@@ -77,17 +77,27 @@ class memmap(ndarray):
         return self
 
     def __array_finalize__(self, obj):
-        if obj is not None and not isinstance(obj, memmap):
-            raise ValueError, "Cannot create a memmap array that way"
-        self._mmap = None
+        if obj is not None:
+            if not isinstance(obj, memmap):
+                raise ValueError, "Cannot create a memmap array that way"
+            self._mmap = obj._mmap
+        else:
+            self._mmap = None
 
     def sync(self):
-        self._mmap.flush()
-
-    def close(self):
-        self._mmap.close()
-
-    def __del__(self):
         if self._mmap is not None:
             self._mmap.flush()
-            del self._mmap
+
+    def close(self):
+        if (self.base is self._mmap):
+            self._mmap.close()
+        elif self._mmap is not None:
+            raise ValueError, "Cannot close a memmap that is being used " \
+                  "by another object."
+
+    def __del__(self):
+        self.sync()
+        try:
+            self.close()
+        except ValueError:
+            pass
