@@ -8,9 +8,9 @@ __all__ = ['unravel_index',
            'ndenumerate','ndindex']
 
 import sys
-import types
 import numpy.core.numeric as _nx
 from numpy.core.numeric import asarray, ScalarType, array
+import math
 
 import function_base
 import numpy.core.defmatrix as matrix
@@ -34,7 +34,7 @@ def unravel_index(x,dims):
     """
     if x > _nx.prod(dims)-1 or x < 0:
         raise ValueError("Invalid index, must be 0 <= x <= number of elements.")
-        
+
     idx = _nx.empty_like(dims)
 
     # Take dimensions
@@ -109,6 +109,7 @@ class nd_grid(object):
                    [2, 2, 2, 2, 2],
                    [3, 3, 3, 3, 3],
                    [4, 4, 4, 4, 4]],
+           <BLANKLINE>
                   [[0, 1, 2, 3, 4],
                    [0, 1, 2, 3, 4],
                    [0, 1, 2, 3, 4],
@@ -119,7 +120,12 @@ class nd_grid(object):
 
            >>> ogrid = nd_grid(sparse=True)
            >>> ogrid[0:5,0:5]
-           [array([[0],[1],[2],[3],[4]]), array([[0, 1, 2, 3, 4]])]
+           [array([[0],
+                  [1],
+                  [2],
+                  [3],
+                  [4]]), array([[0, 1, 2, 3, 4]])]
+
     """
     def __init__(self, sparse=False):
         self.sparse = sparse
@@ -136,7 +142,7 @@ class nd_grid(object):
                     size.append(int(abs(step)))
                     typ = float
                 else:
-                    size.append(int((key[k].stop - start)/(step*1.0)))
+                    size.append(math.ceil((key[k].stop - start)/(step*1.0)))
                 if isinstance(step, float) or \
                     isinstance(start, float) or \
                     isinstance(key[k].stop, float):
@@ -275,7 +281,7 @@ class concatenator(object):
                     newobj = array(newobj, copy=False, subok=True,
                                    ndmin=ndmin)
                     if trans1d != -1 and tempobj.ndim < ndmin:
-                        k2 = ndmin-tempobj.ndim                        
+                        k2 = ndmin-tempobj.ndim
                         if (trans1d < 0):
                             trans1d += k2 + 1
                         defaxes = range(ndmin)
@@ -313,18 +319,15 @@ class r_class(concatenator):
         For example:
         >>> r_[array([1,2,3]), 0, 0, array([4,5,6])]
         array([1, 2, 3, 0, 0, 4, 5, 6])
+
     """
     def __init__(self):
         concatenator.__init__(self, 0)
 
 r_ = r_class()
 
-import warnings
-
 class c_class(concatenator):
     """Translates slice objects to concatenation along the second axis.
-
-       This is equivalent to r_['-1,2,0',...]
     """
     def __init__(self):
         concatenator.__init__(self, -1, ndmin=2, trans1d=0)
@@ -360,15 +363,15 @@ class ndindex(object):
     will then return an N-dimensional counter.
 
     Example:
-    >>> for index in ndindex(4,3,2):
-            print index
-    (0,0,0)
-    (0,0,1)
-    (0,1,0)
-    ...
-    (3,1,1)
-    (3,2,0)
-    (3,2,1)
+    >>> for index in ndindex(3,2,1):
+    ...     print index
+    (0, 0, 0)
+    (0, 1, 0)
+    (1, 0, 0)
+    (1, 1, 0)
+    (2, 0, 0)
+    (2, 1, 0)
+
     """
 
     def __init__(self, *args):
