@@ -4,6 +4,13 @@
 #include "numpy/libnumarray.h"
 #include <float.h>
 
+#if defined(__GLIBC__) || defined(__APPLE__) || defined(__MINGW32__)
+#include <fenv.h>
+#elif defined(__CYGWIN__)
+#include "numpy/fenv/fenv.h"
+#include "numpy/fenv/fenv.c"
+#endif
+
 static PyObject *pCfuncClass;
 static PyTypeObject CfuncType;
 static PyObject *pHandleErrorFunc;
@@ -224,8 +231,7 @@ static int int_dividebyzero_error(long value, long unused) {
 }
 
 /* Likewise for Integer overflows */
-#if defined(linux)
-#include <fenv.h>
+#if defined(__GLIBC__) || defined(__APPLE__) || defined(__CYGWIN__) || defined(__MINGW32__)
 static int int_overflow_error(Float64 value) { /* For x86_64 */
 	feraiseexcept(FE_OVERFLOW);
 	return (int) value;
@@ -2933,13 +2939,7 @@ NA_checkFPErrors(void)
 	return retstatus;
 }
 
-#elif defined(linux) || defined(darwin) || defined(__CYGWIN__)
-
-#if defined(__GLIBC__) || defined(darwin) || defined(__MINGW32__)
-#include <fenv.h>
-#elif defined(__CYGWIN__)
-#include <mingw/fenv.h>
-#endif
+#elif defined(__GLIBC__) || defined(__APPLE__) || defined(__CYGWIN__) || defined(__MINGW32__)
 
 static int 
 NA_checkFPErrors(void)
