@@ -12,8 +12,6 @@ ArgumentError = ValueError
 import numpy.random.mtrand as mt
 import numpy as Numeric
 
-from types import IntType
-
 def seed(x=0, y=0):
     if (x == 0 or y == 0):
         mt.seed()
@@ -42,16 +40,16 @@ def uniform(minimum, maximum, shape=[]):
 def randint(minimum, maximum=None, shape=[]):
     """randint(min, max, shape=[]) = random integers >=min, < max
     If max not given, random integers >= 0, <min"""
-    if not isinstance(minimum, IntType):
+    if not isinstance(minimum, int):
         raise ArgumentError, "randint requires first argument integer"
     if maximum is None:
         maximum = minimum
         minimum = 0
-    if not isinstance(maximum, IntType):
+    if not isinstance(maximum, int):
         raise ArgumentError, "randint requires second argument integer"
     a = ((maximum-minimum)* random(shape))
-    if isinstance(a, Numeric.ArrayType):
-        return minimum + a.astype(Numeric.Int)
+    if isinstance(a, Numeric.ndarray):
+        return minimum + a.astype(Numeric.int)
     else:
         return minimum + int(a)
 
@@ -83,13 +81,13 @@ def multivariate_normal(mean, cov, shape=[]):
     """multivariate_normal(mean, cov) or multivariate_normal(mean, cov, [m, n, ...])
     returns an array containing multivariate normally distributed random numbers
     with specified mean and covariance.
-    
+
     mean must be a 1 dimensional array. cov must be a square two dimensional
     array with the same number of rows and columns as mean has elements.
-    
+
     The first form returns a single 1-D array containing a multivariate
     normal.
-    
+
     The second form returns an array of shape (m, n, ..., cov.shape[0]).
     In this case, output[i,j,...,:] is a 1-D array containing a multivariate
     normal."""
@@ -119,7 +117,7 @@ def gamma(a, r, shape=[]):
 def F(dfn, dfd, shape=[]):
     """F(dfn, dfd) or F(dfn, dfd, [n, m, ...]) returns array of F distributed random numbers with dfn degrees of freedom in the numerator and dfd degrees of freedom in the denominator."""
     if shape == []:
-        shape == None
+        shape = None
     return mt.f(dfn, dfd, shape)
 
 def noncentral_F(dfn, dfd, nconc, shape=[]):
